<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Die Überprüfung ist fast beendet, Danke für Ihre Geduld</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Vorbereiten</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Auf einige Fehler überprüft</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Zum Schreibtisch wechseln</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Willkommen, System erfolgreich aktualisiert</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Aktuelle Version:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Aktualisierungen erfolgreich</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ihr Computer wird bald neu gestartet %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ihr Computer wird bald ausgeschaltet %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Die automatische Neustart-Prozedur schlug fehl. Bitte versuchen Sie ihr Gerät selbst neuzustarten.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Die automatische erunterfahren-Prozedur schlug fehl. Bitte versuchen Sie ihr Gerät selbst herunterzufahren.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Aktualisierungsprotokolle ansehen</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Aktualisierungsprotokolle zuklappen</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Das Protokoll wurde auf den Schreibtisch gespeichert</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Exportieren des Protokolls schlug fehl, bitte erneut versuchen</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Aktualisierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Sicherung fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Es kann keine Systemsicherung durchgeführt werden. Wenn Sie die Aktualisierungen fortsetzen, können Sie später nicht zum alten System zurückkehren.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Unzureichender Speicherplatz. Bitte bereinigen Sie Ihre Festplatte und versuchen Sie es erneut.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Datensicherungsdienste konnten nicht erreicht werden. Bitte überprüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Aktualisierungsdienste konnten nicht erreicht werden. Bitte überprüfen und erneut versuchen.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Abhängigkeitsfehler</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-Fehler</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Erneut sichern</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Aktualisierung fortsetzen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Zum Schreibtisch wechseln</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Vorbereitungen für Aktualisierungen …</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Erzwingen Sie kein Herunterfahren oder Ausschalten, wenn Sie Aktualisierungen installieren. Andernfalls kann Ihr System beschädigt werden.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Aktualisierungsprotokolle ansehen</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Aktualisierungsprotokolle zuklappen</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>Aktualisierungsprotokoll</translation>
    </message>
</context>
</TS>